==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebPinColumnEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebPinColumnEventArgsDetailDescription } from "./WebPinColumnEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPinColumnEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPinColumnEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPinColumnEventArgsDetailDescriptionMetadata.a == null) {
                WebPinColumnEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPinColumnEventArgsDetailDescriptionMetadata.c(WebPinColumnEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPinColumnEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPinColumnEventArgsDetailDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:PinColumnEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Column", "ExportedType:WebColumn");
            a.item("InsertAtIndex", "Number:double");
            a.item("IsPinned", "Boolean");
        }
        static d(a) {
            WebPinColumnEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebPinColumnEventArgsDetail", () => new WebPinColumnEventArgsDetailDescription());
            a.ac("WebPinColumnEventArgsDetail", WebPinColumnEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPinColumnEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPinColumnEventArgsDetailDescriptionMetadata, 'WebPinColumnEventArgsDetailDescriptionMetadata');
    WebPinColumnEventArgsDetailDescriptionMetadata.a = null;
    return WebPinColumnEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebPinColumnEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebPinColumnEventArgsDetailDescription } from "./WebPinColumnEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPinColumnEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPinColumnEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPinColumnEventArgsDetailDescriptionMetadata.a == null) {
                WebPinColumnEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPinColumnEventArgsDetailDescriptionMetadata.c(WebPinColumnEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPinColumnEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPinColumnEventArgsDetailDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:PinColumnEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Column", "ExportedType:WebColumn");
            a.item("InsertAtIndex", "Number:double");
            a.item("IsPinned", "Boolean");
        }
        static d(a) {
            WebPinColumnEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebPinColumnEventArgsDetail", () => new WebPinColumnEventArgsDetailDescription());
            a.ad("WebPinColumnEventArgsDetail", WebPinColumnEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPinColumnEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPinColumnEventArgsDetailDescriptionMetadata, 'WebPinColumnEventArgsDetailDescriptionMetadata');
    WebPinColumnEventArgsDetailDescriptionMetadata.a = null;
    return WebPinColumnEventArgsDetailDescriptionMetadata;
})();
